From: Edward Shishkin <edward.shishkin@gmail.com>
To: ReiserFS Development mailing list <reiserfs-devel@vger.kernel.org>
Subject: [patch 1/2] reiser4: port for Linux-3.14
Date: Mon, 05 May 2014 18:13:41 +0200 [thread overview]
Message-ID: <5367B8B5.2040605@gmail.com> (raw)
[-- Attachment #1: Type: text/plain, Size: 1 bytes --]
[-- Attachment #2: 01-reiser4-port-to-3.14.patch --]
[-- Type: text/x-patch, Size: 2836 bytes --]
Port reiser4 to linux-3.14 (From Mathieu Belanger)
Signed-off-by: Edward Shishkin <edward.shishkin@gmail.com>
diff -urN linux-3.14.1/fs/reiser4/status_flags.c linux-3.14.1.mat/fs/reiser4/status_flags.c
--- linux-3.14.1/fs/reiser4/status_flags.c 2014-04-21 13:02:41.000000000 +0200
+++ linux-3.14.1.mat/fs/reiser4/status_flags.c 2014-04-21 12:59:32.000000000 +0200
@@ -45,13 +45,13 @@
bio = bio_alloc(reiser4_ctx_gfp_mask_get(), 1);
if (bio != NULL) {
- bio->bi_sector = block * (sb->s_blocksize >> 9);
+ bio->bi_iter.bi_sector = block * (sb->s_blocksize >> 9);
bio->bi_bdev = sb->s_bdev;
bio->bi_io_vec[0].bv_page = page;
bio->bi_io_vec[0].bv_len = sb->s_blocksize;
bio->bi_io_vec[0].bv_offset = 0;
bio->bi_vcnt = 1;
- bio->bi_size = sb->s_blocksize;
+ bio->bi_iter.bi_size = sb->s_blocksize;
bio->bi_end_io = reiser4_status_endio;
} else {
__free_pages(page, 0);
@@ -150,7 +150,7 @@
bio->bi_io_vec[0].bv_len = sb->s_blocksize;
bio->bi_io_vec[0].bv_offset = 0;
bio->bi_vcnt = 1;
- bio->bi_size = sb->s_blocksize;
+ bio->bi_iter.bi_size = sb->s_blocksize;
bio->bi_end_io = reiser4_status_endio;
lock_page(get_super_private(sb)->status_page); /* Safe as nobody should
* touch our page. */
diff -urN linux-3.14.1/fs/reiser4/wander.c linux-3.14.1.mat/fs/reiser4/wander.c
--- linux-3.14.1/fs/reiser4/wander.c 2014-04-21 13:02:41.000000000 +0200
+++ linux-3.14.1.mat/fs/reiser4/wander.c 2014-04-21 12:59:33.000000000 +0200
@@ -736,7 +736,7 @@
return RETERR(-ENOMEM);
bio->bi_bdev = super->s_bdev;
- bio->bi_sector = block * (super->s_blocksize >> 9);
+ bio->bi_iter.bi_sector = block * (super->s_blocksize >> 9);
for (nr_used = 0, i = 0; i < nr_blocks; i++) {
struct page *pg;
@@ -823,7 +823,7 @@
}
if (nr_used > 0) {
assert("nikita-3453",
- bio->bi_size == super->s_blocksize * nr_used);
+ bio->bi_iter.bi_size == super->s_blocksize * nr_used);
assert("nikita-3454", bio->bi_vcnt == nr_used);
/* Check if we are allowed to write at all */
reply other threads:[~2014-05-05 16:13 UTC|newest]
Thread overview: [no followups] expand[flat|nested] mbox.gz Atom feed
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=5367B8B5.2040605@gmail.com \
--to=edward.shishkin@gmail.com \
--cc=reiserfs-devel@vger.kernel.org \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.
diff -urN linux-3.14.1/fs/reiser4/page_cache.c linux-3.14.1.mat/fs/reiser4/page_cache.c
--- linux-3.14.1/fs/reiser4/page_cache.c 2014-04-21 13:02:41.000000000 +0200
+++ linux-3.14.1.mat/fs/reiser4/page_cache.c 2014-04-21 12:59:32.000000000 +0200
@@ -438,10 +438,10 @@
assert("nikita-2276", !reiser4_blocknr_is_fake(&blocknr));
bio->bi_bdev = super->s_bdev;
/* fill bio->bi_sector before calling bio_add_page(), because
* q->merge_bvec_fn may want to inspect it (see
* drivers/md/linear.c:linear_mergeable_bvec() for example. */
- bio->bi_sector = blocknr * (blksz >> 9);
+ bio->bi_iter.bi_sector = blocknr * (blksz >> 9);
if (!bio_add_page(bio, page, blksz, 0)) {
warning("nikita-3452",
@@ -438,10 +438,10 @@
assert("nikita-2276", !reiser4_blocknr_is_fake(&blocknr));
bio->bi_bdev = super->s_bdev;
- /* fill bio->bi_sector before calling bio_add_page(), because
+ /* fill bio->bi_iter.bi_sector before calling bio_add_page(), because
* q->merge_bvec_fn may want to inspect it (see
* drivers/md/linear.c:linear_mergeable_bvec() for example. */